# needs some secrets
```
# .env
GITHUB_TOKEN=ghp_xxx
OPENAI_API_KEY=sk-xxx
PREFECT_API_URL=https://api.prefect.cloud/api/accounts/xxx/workspaces/xxx
PREFECT_API_KEY=pnu_xxx
PREFECT_LOGGING_LEVEL=DEBUG
PREFECT_EXPERIMENTAL_ENABLE_TASK_SCHEDULING=True
```